/*
Clear Weather 0.7.0
Jonathan Dale

Original coding and design by Scott Bradford Creative Enterprises
Updated, including Touchpad full screen support, by Jonathan Dale

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/


function FirstAssistant() {
	/* this is the creator function for your scene assistant object. It will be passed all the 
	   additional parameters (after the scene name) that were passed to pushScene. The reference
	   to the scene controller (this.controller) has not be established yet, so any initialization
	   that needs the scene controller should be done in the setup function below. */
}

FirstAssistant.prototype.setup = function() {
	/* this function is for setup tasks that have to happen when the scene is first created */
		
	/* use Mojo.View.render to render view templates and add them to the scene, if needed */
	
	/* setup widgets here */
	
	/* update the app info using values from our app */
	/*this.controller.get("app-title").update(Mojo.appInfo.title);
	this.controller.get("app-id").update(Mojo.appInfo.id);
	this.controller.get("app-version").update(Mojo.appInfo.version);*/

	// Set up the application menu
	this.appMenuModel = {
	   items:[
	       { label: 'About Clear Weather', command: 'showAboutScreen' },
	       { label: 'Preferences...', command: 'showPrefsScreen' },
	       Mojo.Menu.helpItem
	   ]};
	
	// Set up the nice menu across the top
	this.viewMenuModel = { items: [
	   { items:[
	       { label: 'Forecast', icon: '', command: 'showForecastView', width: 107 },
	       { label: 'Warnings', icon: '', command: 'showWarningView', width: 106 },
	       { label: 'Radar', icon: '', command: 'showRadarView', width: 107 }
	   ], toggleCmd:'showForecastView'}
	]};
	
	// Set up the refresh button at the bottom right
	this.cmdMenuModel = {
	    visible: true,
	    items: [
	        {items:[{label: $L('Refresh'), icon:'refresh', command:'refresh'}]}
	    ]};
		
	this.controller.setupWidget (Mojo.Menu.viewMenu, { menuClass:'true' }, this.viewMenuModel);
	this.controller.setupWidget (Mojo.Menu.appMenu, { omitDefaultItems: true }, this.appMenuModel);
	this.controller.setupWidget (Mojo.Menu.commandMenu, undefined, this.cmdMenuModel);
	
	this.controller.setupWidget("radar",
	        this.attributes = {
	            mode: 'free'
	        }
	    ); 
	
	/* add event handlers to listen to events from widgets */
};

FirstAssistant.prototype.activate = function(event) {
	
	/* put in event handlers here that should only be in effect when this scene is active. For
	   example, key handlers that are observing the document */
	
	nnwClearAll();
	
	if (nnwUseLocation == true) {	
		// Get GPS Location
		nnwThrowMessage("Determining GPS Location...","all");
	    this.controller.serviceRequest('palm://com.palm.location', {
			method : 'getCurrentPosition',
	        parameters: {
				responseTime: 2,
	            subscribe: false
	                },
	        onSuccess: this.handleGPSPosition.bind(this),
	        onFailure: this.handleGPSError.bind(this)
	    });
	} else {
		nnwGetZipForecast(nnwZipCode);
	}
	
};

FirstAssistant.prototype.deactivate = function(event) {
	/* remove any event handlers you added in activate and do any other cleanup that should happen before
	   this scene is popped or another scene is pushed on top */
};

FirstAssistant.prototype.cleanup = function(event) {
	/* this function should do any cleanup needed before the scene is destroyed as 
	   a result of being popped off the scene stack */
};

FirstAssistant.prototype.handleCommand = function(event) {
    this.controller=Mojo.Controller.stageController.activeScene();
    if(event.type == Mojo.Event.command) {
        switch(event.command) {
            case 'showAboutScreen':
                this.controller.showAlertDialog({
                    onChoose: function(value) {},
                    title: $L("Clear Weather 0.7.0"),
                    message: $L("<p>Copyright &copy; 2011,<br /><a href='http://www.madreporite.com/weather/'>Jonathan Dale</a><br />Original coding and design by <a href='http://www.scottbradford.us/'>Scott Bradford</a><br />Licensed under the <a href='http://www.gnu.org/licenses/gpl-2.0.html'>GNU GPL 2.0</a></p><p>Data, icons, and maps provided by the <a href='http://www.weather.gov'>U.S. National Weather Service</a></p>"),
                    choices:[
                        {label:$L("OK"), value:""}
                    ],
                    allowHTMLMessage: true
                });
                break;
            case 'showPrefsScreen':
            	this.controller.stageController.pushScene("preferences");
            	break;
            case 'showForecastView':
            	this.controller.getSceneScroller().mojo.scrollTo(0,0);
            	this.controller.getSceneScroller().mojo.setMode('vertical');
            	jQuery('#warningPane').hide();
            	jQuery('#radarPane').hide();
                jQuery('#forecastPane').show();
            	jQuery('#locationStatus').show();
                break;
            case 'showWarningView':
            	this.controller.getSceneScroller().mojo.scrollTo(0,0);
            	this.controller.getSceneScroller().mojo.setMode('vertical');
                jQuery('#forecastPane').hide();
                jQuery('#radarPane').hide();
            	jQuery('#warningPane').show();
            	jQuery('#locationStatus').show();
                break;
            case 'showRadarView':
            	this.controller.getSceneScroller().mojo.scrollTo(0,0);
            	this.controller.getSceneScroller().mojo.setMode('free');
            	jQuery('#forecastPane').hide();
            	jQuery('#warningPane').hide();
            	jQuery('#radarPane').show();
            	jQuery('#locationStatus').hide();
                break;
            case 'refresh':
            	this.controller.stageController.swapScene("first");
                break;
        }
    }

};

// Handle GPS Positive Response
FirstAssistant.prototype.handleGPSPosition = function(event) {
	  latitude = event.latitude;
	  longitude = event.longitude;
	  latlon = new Array(latitude.toFixed(4),longitude.toFixed(4))

	  nnwGetForecast(latlon);
}

// Handle GPS Error
FirstAssistant.prototype.handleGPSError = function(event) {
	nnwThrowMessage("GPS Location Error...","all");
}

// output errors and messages (required by nnw-lib)
function nnwThrowMessage(message,spot) {
	if (spot == 'forecast') {
		jQuery('#forecastStatus').show();
		jQuery('#forecastStatus').html('<p>' + message + '</p>');
		if (message == '') {
			jQuery('#forecastStatus').hide();
		} else {
			jQuery('#forecastStatus').show();
		}
	} else if (spot == 'warning') {
		jQuery('#warningStatus').html('<p>' + message + '</p>');
		if (message == '') {
			jQuery('#warningStatus').hide();
		} else {
			jQuery('#warningStatus').show();
		}
	} else if (spot == 'radar') {
		jQuery('#radarStatus').html('<p>' + message + '</p>');
		if (message == '') {
			jQuery('#radarStatus').hide();
		} else {
			jQuery('#radarStatus').show();
		}
	} else if (spot == 'all') {
		jQuery('#forecastStatus').html('<p>' + message + '</p>');
		jQuery('#warningStatus').html('<p>' + message + '</p>');
		jQuery('#radarStatus').html('<p>' + message + '</p>');
		if (message == '') {
			jQuery('#forecastStatus').hide();
			jQuery('#warningStatus').hide();
			jQuery('#radarStatus').hide();
		} else {
			jQuery('#forecastStatus').show();
			jQuery('#warningStatus').show();
			jQuery('#radarStatus').show();
		}
	}
}

// handle the output of the five-day forecast (required by cw-lib)
function nnwDisplayForecast(dataReturn,warningReturn,locationName,locationURL) {
	// clear out any existing forecast html
	jQuery('#forecast').html('');
	for (c=0;c<=9;c++) {
		// funky logic to handle two arrays of temps; uses 'ight' to catch 'Tonight' and 'X Night'
		if (dataReturn[c][0].indexOf("ight") >= 0) {
			temp = 'Low: ';
		} else {
			temp = 'High: ';
		}
		if (nnwTempScale == "C") {
			temp = temp + Math.round(((dataReturn[c][1])-32)/1.8) + '&deg; C';
		} else {
			temp = temp + dataReturn[c][1] + '&deg; F';
		}
		// real output
		jQuery('#forecast').append('<table class="palm-divider labeled"><tr><td class="left"></td><td class="label">' + dataReturn[c][0] + '</td><td class="right"></td></tr></table>')
		jQuery('#forecast').append('<div class="forecastDay"><img src="' + dataReturn[c][2] + '" /><p>' + temp + '<br />' + dataReturn[c][3] + '<br />' + dataReturn[c][4] + '% chance of precipitation</p><p class="detail">' + dataReturn[c][5] + '</p></div>');
	}
	jQuery('#locationText').append('<br /><a href="' + locationURL + '">' + locationName + '</a>');
	
	// clear out any existing warning html
	jQuery('#warning').html('');
	
	if (warningReturn.length == 0) {
		// throw a message if there are no warnings
		nnwThrowMessage("There are no current warnings,<br />watches, or advisories.","warning")
	} else {
		// output the warnings if there are any
		for (c=0;c<warningReturn.length;c++) {
			jQuery('#warning').append('<table id="tableWarning'+c+'" class="palm-divider collapsible label" onclick="nnwToggleWarning(\''+c+'\')"><tbody><tr><td class="left"></td><td class="label">' + warningReturn[c][0] + '</td><td class="line" width="100%"></td><td><div id="arrowWarning'+c+'" class="palm-arrow-closed arrow_button"></div></td><td class="right"></td></tr></tbody></table>');
			jQuery('#warning').append('<div class="warningContent hidden" id="drawerWarning'+c+'"><p>Please wait...</p></div>');
			nnwGetWarning(warningReturn[c][1],c);
		}
		// open up the 1st warning if there is only one; no sense leaving it closed!
		if (warningReturn.length == 1) {
			nnwToggleWarning(0);
		}
	}		
}

//handle the output of the warning contents (required by nnw-lib)
function nnwDisplayWarning(dataReturn,warnID) {
	jQuery('div#drawerWarning'+warnID).html(dataReturn);
}

function nnwToggleWarning(warnID) {
	warningContent = '#drawerWarning'+warnID;
	warningArrow = '#arrowWarning'+warnID;
	if (jQuery(warningContent).is(':visible')){
		jQuery(warningContent).hide();
		jQuery(warningArrow).removeClass('palm-arrow-expanded');
		jQuery(warningArrow).addClass('palm-arrow-closed');
	} else {
		jQuery(warningContent).show();
		jQuery(warningArrow).removeClass('palm-arrow-closed');
		jQuery(warningArrow).addClass('palm-arrow-expanded');
	}
}

function nnwDisplayMap(mapStaticURL,mapMovingURL) {
	if (nnwAnimateMaps == true) {
		mapURL = mapMovingURL;
	} else {
		mapURL = mapStaticURL;
	}
	
	jQuery('#radar').html('<img src="'+mapURL+'" />');
}

function nnwClearAll() {
	nnwThrowMessage('','all');
	jQuery('.content').html('');
}