/*
Clear Weather 0.7.0
Jonathan Dale

Original coding and design by Scott Bradford Creative Enterprises
Updated, including Touchpad full screen support, by Jonathan Dale

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

function PreferencesAssistant() {
	/* this is the creator function for your scene assistant object. It will be passed all the 
	   additional parameters (after the scene name) that were passed to pushScene. The reference
	   to the scene controller (this.controller) has not be established yet, so any initialization
	   that needs the scene controller should be done in the setup function below. */
}

PreferencesAssistant.prototype.setup = function() {
	/* this function is for setup tasks that have to happen when the scene is first created */
		
	/* use Mojo.View.render to render view templates and add them to the scene, if needed */
	
	/* setup widgets here */
	
	/* add event handlers to listen to events from widgets */
	
    // set up the three pref widgets
    this.controller.setupWidget("locationToggle",
    		{},
    		this.locationToggleModel = {
    			value: nnwUseLocation
    		});
    this.controller.setupWidget("zipEntry",
    		{ hintText: 'Enter ZIP Code (if GPS is off)',
    		  changeOnKeyPress: true,
    		  modifierState: Mojo.Widget.numLock,
    		  maxLength: 5 },
    		this.zipEntryModel = {
    			value: nnwZipCode
    		});
    this.controller.setupWidget("tempScale",
    		{ choices: [
    		     {label: 'Fahrenheit', value: 'F'},
    		     {label: 'Celsius', value: 'C'}
    		     ]},
    		this.tempScaleModel = {
    		     value: nnwTempScale
    		});
    this.controller.setupWidget("animationToggle",
    		{},
    		this.animationToggleModel = {
    			value: nnwAnimateMaps
    		});
    
    
    // add a back button for the Touchpad (this doesn't check, it just goes ahead and adds it, so it will also appear on other devices)
    var menuModel = {
    
                 visible: true,
                 items: [
                        { icon: "back", command: "goBack"}
                 ]
             };
    
         this.controller.setupWidget(Mojo.Menu.commandMenu,
             this.attributes = {
                 spacerHeight: 0,
                 menuClass: 'no-fade'
             },
             menuModel
     );   
    // end of the part added for the Touchpad
    
    
    // handle any changes to the location widget
    this.changeLocationHandler = this.changeLocation.bindAsEventListener(this);
    this.controller.listen("locationToggle", Mojo.Event.propertyChange, this.changeLocationHandler);
    
    // handle changes to the zip code
    this.changeZipHandler = this.zipChanges.bindAsEventListener(this)
    this.controller.listen('zipEntry', Mojo.Event.propertyChange, this.changeZipHandler);
    
    // handle any changes to the tempscale
    this.changeTempHandler = this.tempChanges.bindAsEventListener(this)
    this.controller.listen('tempScale', Mojo.Event.propertyChange, this.changeTempHandler);
    
 // handle any changes to the animation setting
    this.changeAnimationHandler = this.changeAnimation.bindAsEventListener(this);
    this.controller.listen("animationToggle", Mojo.Event.propertyChange, this.changeAnimationHandler);
 
};

PreferencesAssistant.prototype.activate = function(event) {
	/* put in event handlers here that should only be in effect when this scene is active. For
	   example, key handlers that are observing the document */
	   
	   	// added to handle the Back button on the Touchpad
	   	this.handleCommand = function(event) {
	   		if(event.type == Mojo.Event.command) {
	   			switch (event.command) {
	   				case "goBack":
	   					this.controller.stageController.popScene();
	   					break;
	   			}
	   		}
		};
		// end of part added for Touchpad	   
	   
};

PreferencesAssistant.prototype.deactivate = function(event) {
	/* remove any event handlers you added in activate and do any other cleanup that should happen before
	   this scene is popped or another scene is pushed on top */
	cookieData.put({
		useLocation: nnwUseLocation,
		zipCode: nnwZipCode,
		tempScale: nnwTempScale,
		animateMaps: nnwAnimateMaps
	});
};

PreferencesAssistant.prototype.cleanup = function(event) {
	/* this function should do any cleanup needed before the scene is destroyed as 
	   a result of being popped off the scene stack */
	this.controller.stopListening("locationToggle", Mojo.Event.propertyChange, this.changeLocationHandler);
};

// handle the location toggler
PreferencesAssistant.prototype.changeLocation = function(event) {
	nnwUseLocation = this.locationToggleModel.value;
};

// handle the zip code entry
PreferencesAssistant.prototype.zipChanges = function(event){
	nnwZipCode = this.zipEntryModel.value;
}

// handle the temp. scale
PreferencesAssistant.prototype.tempChanges = function(event){
	nnwTempScale = this.tempScaleModel.value;
}

//handle the animation setting
PreferencesAssistant.prototype.changeAnimation = function(event){
	nnwAnimateMaps = this.animationToggleModel.value;
}