/*
Clear Weather 0.7.0
Jonathan Dale

Original coding and design by Scott Bradford Creative Enterprises
Updated, including Touchpad full screen support, by Jonathan Dale

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/*
 * For this to work correctly, you need your own JS with at least these functions to handle feedback into your app/page:
 * 
 *    nnwThrowMessage(message,component)
 *    	display 'message', which is an error or a title
 *      'component' is where to display it; will be 'forecast', 'warning', or 'all'
 *    nnwDisplayForecast(dataReturn,warningReturn)
 *      display 'dataReturn' array of 5-day forecast info
 *      Array structure is like this:
 *    		0
 *				Period Name (Today, Tomorrow, etc.)
 *     	 		Temp (either low or high, Fahrenheit, integer so you can work with it/convert it if needed).
 *       		Default Condition Icon (NWS url)
 *       		Short Condition Description
 *       		XX (% chance of precipitation, integer)
 *    		1
 *    			Period Name (....)
 *    nnwDisplayWarning(warnFormatted,warnID)
 *       display 'warnFormatted' HTML content in warning div#warning0 where 0 is the warnID.
 *    nnwDisplayMap(mapStaticURL,mapMovingURL)
 *    	 display radar for NWS map code; passes in both the static and the animated images
 */

//variables and constants
var latlon = new Array();

// convert a ZIP code into a usable latitude and longitude
function nnwGetZipForecast(zipCode) {
	// simple zip validation
	// this is VERY simple, but will reduce invalid and unnecessary hits to the NWS site
	if ((isNaN(zipCode)) || zipCode > 99950 || zipCode < 00501) {
		nnwThrowMessage("Enter a valid U.S. ZIP Code...","all");
		return false;
	} else {
		jQuery.ajax({
			type: 'GET',
			url: 'http://www.weather.gov/forecasts/xml/SOAP_server/ndfdXMLclient.php',
			//url: './example-xml/example-zip.xml',
			dataType: 'xml',
			data: 'whichClient=LatLonListZipCode&listZipCodeList=' + zipCode,
			beforeSend: nnwThrowMessage('Requesting Weather Data...','all'),
			error: function(req,err) {
				nnwThrowMessage('There has been an error loading information from the National Weather Service. This is usually a temporary problem.' + err,'all');
			},
			success: function(dataStream) {
				latlonString = jQuery(dataStream).find('latLonList').text();
				latlon = new Array();
				latlon = latlonString.split(',');
				nnwGetForecast(latlon);
			}
		});
	}
}

// get the weather (jquery ajax request) and parse it
// NWS provides ~7 days, but the last couple are useless so I drop it to a 5-day
function nnwGetForecast(latlon) {
	// output the latlon
	jQuery('#locationStatus').html('<p id="locationText"><strong>Location</strong><br />Latitude: ' + latlon[0] + '<br />Longitude: ' + latlon[1] + '</p>');
	
	locationString = 'lat=' + latlon[0] + '&lon=' + latlon[1];
	
	// make the ajax request
	jQuery.ajax({
		type: 'GET',
		url: 'http://forecast.weather.gov/MapClick.php', // real nws url, for device app use
		//url: './example-xml/example-5day.xml', // test xml
		//url: './example-xml/example-5day-error.xml', // test xml with error
		//url: './example-xml/example-5day-statement.xml', // test xml with weather statement
		//url: './example-xml/example-5day-warning.xml', // test xml with warnings/alerts
		dataType: 'xml',
		data: locationString + '&FcstType=dwml',
		beforeSend: nnwThrowMessage('Requesting Weather Data...','all'),
		error: function(req,err) {
			nnwThrowMessage('Weather data is currently unavailable for your location. This is usually caused by temporary problems with the NWS web site. Please try again later.','all');
		},
		success: function(dataStream) {
			nnwThrowMessage("Processing...",'all');
			
			// detect if the xml returned by NWS has a 'problem' and report it
			var problems = jQuery(dataStream).find("problem");
			if (problems.length != 0) {
				nnwThrowMessage('NWS has returned an error...','all');
			} else {
				// if no problems, go ahead and parse!
				nnwThrowMessage('','all');
				
				// prepare the forecast arrays
				periodName = new Array();
				hiTemp = new Array();
				loTemp = new Array();
				condition = new Array();
				conditionIcon = new Array();
				precipPct = new Array();
				conditionDetail = new Array();
				
				// get day/night period names
				jQuery(dataStream).find("time-layout").each(function(){
					if ((jQuery(this).find("layout-key").text()).indexOf('k-p12h-') >= 0) {
						jQuery(this).find("start-valid-time").each(function(c){
							periodName[c] = jQuery(this).attr("period-name");
						});
					}
				});
				// get high and low temps (has to be two arrays, for some reason; thanks, NWS!)
				jQuery(dataStream).find("temperature").each(function(){
					if (jQuery(this).attr("type")=="maximum") {
						jQuery(this).find("value").each(function(hi){
							hiTemp[hi] = jQuery(this).text();
						});
					} else if (jQuery(this).attr("type")=="minimum") {
						jQuery(this).find("value").each(function(lo){
							loTemp[lo] = jQuery(this).text();
						});
					}
				});
				// get condition icon urls from the xml
				jQuery(dataStream).find("icon-link").each(function(c){
					conditionIcon[c] = jQuery(this).text();
				});
				// get brief condition descriptions from the xml
				jQuery(dataStream).find("weather-conditions").each(function(c){
					if (jQuery(this).attr("xsi:nil") != "true") {
						condition[c] = jQuery(this).attr("weather-summary");
					} else {
						condition[c] = "NONE";
					}
				});
				// get precip % amounts
				jQuery(dataStream).find("probability-of-precipitation value").each(function(c){
					if (jQuery(this).attr("xsi:nil") != "true") {
						precipPct[c] = jQuery(this).text();
					} else {
						precipPct[c] = "0";
					}
				});
				// get detailed worded forecast
				jQuery(dataStream).find("wordedForecast text").each(function(c) {
					conditionDetail[c] = jQuery(this).text();
				});
				
				// Reorganize the data into a LOGICAL forecast array, as opposed to the NWS gibberish		
				dataReturn = new Array();
				hi=0;
				lo=0;
				offset=0;
				for (c=0;c<=9+offset;c++) {
					// funky logic to handle two arrays of temps; uses 'ight' to catch 'Tonight' and 'X Night'
					if (periodName[c].indexOf("ight") >= 0) {
						temp = loTemp[lo];
						lo++;
					} else {
						temp = hiTemp[hi];
						hi++;
					}
					if (condition[c] != "NONE") {
						dataReturn[c-offset] = new Array(periodName[c],temp,conditionIcon[c],condition[c],precipPct[c],conditionDetail[c]);
					} else {
						offset++;
					}
				}
				
				// prepare the warnings array for output
				warningReturn = new Array();

				// get hazard condition information from the xml
				jQuery(dataStream).find("hazard-conditions").each(function(c){
					if (jQuery(this).attr("xsi:nil") != "true") {
						jQuery(this).find("hazard").first().each(function(){
							headline = jQuery(this).attr("headline");
							hazardURL = jQuery(this).find("hazardTextURL").text();
						});
						warningReturn[c] = new Array(headline,hazardURL);
					}
				});
				
				// get the pretty city/location name and the URL of its NWS forecast page
				if (jQuery(dataStream).find("area-description").text() != '') {
					locationName = jQuery(dataStream).find("area-description").text();
				} else {
					locationName = jQuery(dataStream).find("city").text();
				}
				locationURL = jQuery(dataStream).find("moreWeatherInformation").text();
				
				locationSplitter = locationURL.indexOf('?');
				//locationURLRoot = locationURL.substring(0,(locationSplitter-1));
				//locationURLParams = locationURL.substring(locationSplitter);

                                //added to fix concatenated URLs - JHD
                                locationSplitter = locationURL.indexOf('http://www.nws');
                                if (locationSplitter > -1) {
                                        locationURL = locationURL.substring(0,(locationSplitter-1));
                                }
				
				// get the NWS map code (yes, we have to make a whole second ajax request to get this)
				jQuery.ajax({
					type: 'GET',
					url: locationURL,
					dataType: 'html',
					//data: locationURLParams,
					error: function(req,err) {
						nnwThrowMessage('Error retrieving map: ' + err,'radar');
					},
					success: function(dataStream) {
						locationKey = 'http://radar.weather.gov/radar.php?rid=';
						startPoint = dataStream.indexOf(locationKey) + locationKey.length;
						endPoint = dataStream.indexOf('&',startPoint);
						mapCode = dataStream.substring(startPoint,endPoint).toUpperCase();
						mapStaticURL = 'http://radar.weather.gov/ridge/Thumbs/' + mapCode + '.png';
						mapMovingURL = 'http://radar.weather.gov/ridge/lite/N0R/' + mapCode + '_loop.gif';
						nnwDisplayMap(mapStaticURL,mapMovingURL);
                                                //nnwThrowMessage('mapCode=' + mapCode + '.','all');
                                                //nnwThrowMessage(locationURL,'all');
					}
				});
				
				// execute the output function
				nnwDisplayForecast(dataReturn,warningReturn,locationName,locationURL);

			}
		}
	});
}

function nnwGetWarning(wURL,wID) {
	jQuery.ajax({
		type: 'GET',
		url: wURL,
		dataType: 'html',
		error: function(req,err) {
			nnwThrowMessage('There has been an error: ' + err,'all');
		},
		success: function(dataStream) {
			// pull out the warning content (assuming NWS doesn't change anything)
			warnRawContent = jQuery(dataStream).find("pre").html();
			
			// get the current year; need this to parse out the unnecessary gibberish
			var rightNow = new Date();
			var thisYear = rightNow.getFullYear();
			
			// get the end of the first current year instance
			firstYear = warnRawContent.indexOf(thisYear) + 4;
			// get the position of the end of the second year instance
			contentStart = warnRawContent.indexOf(thisYear,firstYear) + 6;
			
			// turn it into pretty HTML paragraphs
			warnFormatted = '<p>' + warnRawContent.substring(contentStart).replace(/\n\n/g,'</p><p>') + '</p>';
			
			nnwDisplayWarning(warnFormatted,wID);
		}
	});
}